==> estateplat-common-1.1.0-20160805.025715-142-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzLq.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 林权
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:23
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_lq")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzLq implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //权利类型
    @XmlElement(name = "qllx")
    private String qllx;
    //发包方
    @XmlElement(name = "fbf")
    private String fbf;
    //使用权（承包）面积
    @XmlElement(name = "syqmj")
    private Double syqmj;
    //林地使用（承包）起始时间
    @XmlElement(name = "ldsyqssj")
    private Date ldsyqssj;
    //林地使用（承包）结束时间
    @XmlElement(name = "ldsyjssj")
    private Date ldsyjssj;
    //林地所有权性质
    @XmlElement(name = "ldsyqxz")
    private String ldsyqxz;
    //森林、林木所有权人
    @XmlElement(name = "sllmsyqr1")
    private String sllmsyqr1;
    //森林、林木使用权人
    @XmlElement(name = "sllmsyqr2")
    private String sllmsyqr2;
    //主要树种
    @XmlElement(name = "zysz")
    private String zysz;
    //株数
    @XmlElement(name = "zs;")
    private Integer zs;
    //林种
    private String lz;
    //起源
    private String qy;
    //造林年度
    private Integer zlnd;
    //林班
    private String lb;
    //小班
    private String xb;
    //小地名
    private String xdm;
    //备注
    private String bz;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getFbf() {
        return fbf;
    }

    public void setFbf(String fbf) {
        this.fbf = fbf;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public Date getLdsyqssj() {
        return ldsyqssj;
    }

    public void setLdsyqssj(Date ldsyqssj) {
        this.ldsyqssj = ldsyqssj;
    }

    public Date getLdsyjssj() {
        return ldsyjssj;
    }

    public void setLdsyjssj(Date ldsyjssj) {
        this.ldsyjssj = ldsyjssj;
    }

    public String getLdsyqxz() {
        return ldsyqxz;
    }

    public void setLdsyqxz(String ldsyqxz) {
        this.ldsyqxz = ldsyqxz;
    }

    public String getSllmsyqr1() {
        return sllmsyqr1;
    }

    public void setSllmsyqr1(String sllmsyqr1) {
        this.sllmsyqr1 = sllmsyqr1;
    }

    public String getSllmsyqr2() {
        return sllmsyqr2;
    }

    public void setSllmsyqr2(String sllmsyqr2) {
        this.sllmsyqr2 = sllmsyqr2;
    }

    public String getZysz() {
        return zysz;
    }

    public void setZysz(String zysz) {
        this.zysz = zysz;
    }

    public Integer getZs() {
        return zs;
    }

    public void setZs(Integer zs) {
        this.zs = zs;
    }

    public String getLz() {
        return lz;
    }

    public void setLz(String lz) {
        this.lz = lz;
    }

    public String getQy() {
        return qy;
    }

    public void setQy(String qy) {
        this.qy = qy;
    }

    public Integer getZlnd() {
        return zlnd;
    }

    public void setZlnd(Integer zlnd) {
        this.zlnd = zlnd;
    }

    public String getLb() {
        return lb;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getXdm() {
        return xdm;
    }

    public void setXdm(String xdm) {
        this.xdm = xdm;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}

==> estateplat-common-1.2.4-20200827.071417-415-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzLq.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 林权
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:23
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_lq")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzLq implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //权利类型
    @XmlElement(name = "qllx")
    private String qllx;
    //发包方
    @XmlElement(name = "fbf")
    private String fbf;
    //使用权（承包）面积
    @XmlElement(name = "syqmj")
    private Double syqmj;
    //林地使用（承包）起始时间
    @XmlElement(name = "ldsyqssj")
    private Date ldsyqssj;
    //林地使用（承包）结束时间
    @XmlElement(name = "ldsyjssj")
    private Date ldsyjssj;
    //林地所有权性质
    @XmlElement(name = "ldsyqxz")
    private String ldsyqxz;
    //森林、林木所有权人
    @XmlElement(name = "sllmsyqr1")
    private String sllmsyqr1;
    //森林、林木使用权人
    @XmlElement(name = "sllmsyqr2")
    private String sllmsyqr2;
    //主要树种
    @XmlElement(name = "zysz")
    private String zysz;
    //株数
    @XmlElement(name = "zs;")
    private Integer zs;
    //林种
    private String lz;
    //起源
    private String qy;
    //造林年度
    private Integer zlnd;
    //林班
    private String lb;
    //小班
    private String xb;
    //小地名
    private String xdm;
    //备注
    private String bz;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    //登簿人
    @XmlElement(name = "dbr")
    private String dbr;

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getFbf() {
        return fbf;
    }

    public void setFbf(String fbf) {
        this.fbf = fbf;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public Date getLdsyqssj() {
        return ldsyqssj;
    }

    public void setLdsyqssj(Date ldsyqssj) {
        this.ldsyqssj = ldsyqssj;
    }

    public Date getLdsyjssj() {
        return ldsyjssj;
    }

    public void setLdsyjssj(Date ldsyjssj) {
        this.ldsyjssj = ldsyjssj;
    }

    public String getLdsyqxz() {
        return ldsyqxz;
    }

    public void setLdsyqxz(String ldsyqxz) {
        this.ldsyqxz = ldsyqxz;
    }

    public String getSllmsyqr1() {
        return sllmsyqr1;
    }

    public void setSllmsyqr1(String sllmsyqr1) {
        this.sllmsyqr1 = sllmsyqr1;
    }

    public String getSllmsyqr2() {
        return sllmsyqr2;
    }

    public void setSllmsyqr2(String sllmsyqr2) {
        this.sllmsyqr2 = sllmsyqr2;
    }

    public String getZysz() {
        return zysz;
    }

    public void setZysz(String zysz) {
        this.zysz = zysz;
    }

    public Integer getZs() {
        return zs;
    }

    public void setZs(Integer zs) {
        this.zs = zs;
    }

    public String getLz() {
        return lz;
    }

    public void setLz(String lz) {
        this.lz = lz;
    }

    public String getQy() {
        return qy;
    }

    public void setQy(String qy) {
        this.qy = qy;
    }

    public Integer getZlnd() {
        return zlnd;
    }

    public void setZlnd(Integer zlnd) {
        this.zlnd = zlnd;
    }

    public String getLb() {
        return lb;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getXdm() {
        return xdm;
    }

    public void setXdm(String xdm) {
        this.xdm = xdm;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}
